@@ -2,7 +2,7 @@ use 5.18.2;
 use Modern::Perl;
 use Moops;
 
-class XML::Simple::Sugar 1.0.2 {
+class XML::Simple::Sugar 1.0.3 {
     our $AUTOLOAD;
     use XML::Simple;
     use UNIVERSAL::isa;
@@ -297,10 +297,12 @@ XML::Simple::Sugar - Sugar sprinkled on XML::Simple
 
 =head1 VERSION
 
-version v1.0.2
+version v1.0.3
 
 =head1 SYNOPSIS
 
+The basics...
+
     use Modern::Perl;
     use Data::Dumper;
     use XML::Simple::Sugar;
@@ -310,50 +312,41 @@ version v1.0.2
     #Autovivify some elements nested within each other, and set the content of the salary element
     $xs->company->departments->department([0])->person([0])->salary(60000);
     
-    #Working with a specific element
     my $departments = $xs->company->departments;
-    
-    #Setting an attribute on the first element in a collection
     $departments->department([0])->xml_attr({ name => 'IT Department', manager => 'John Smith' });
 
-    #Return all person elements in the first department element and say their first names
+    say $xs->xml_write;
+
+    # Or from a child element... (returns a string reflecting the root element's XML)
+    say $departments->xml_write;
+
+Working with existing XML
+
+    my $xs = XML::Simple::Sugar->new({ xml => '<your_xml>here</your_xml>' });
+
+Setting and retrieving content/attributes
+
+    # Return all person elements in the first department element and say their first names
     map{ say $_->first_name->xml_content; } $xs->company->departments->department([0])->person(['all']);
     
-    #Setting the content of elements
+    # Setting the content of elements
     my $person = $xs->company->departments->department([0])->person([0]);
     $person->first_name('John')->last_name('Smith')->email('jsmith@example.com');
-    
-    #Setting an attribute with attr
-    $person->xml_attr({ skills => 'Perl' });
-    
-    #Or optionally setting attributes with a hashref
-    $xs->company->departments->department([0])->person([0])->salary({ 'jobgrade' => 10, 'exempt' => 1 });
-    
-    #Inspect the attributes of an element
-    say Data::Dumper::Dumper($person->xml_attr);
-    
-    #Set and retrieve the string contents of an element
+    # Or, using xml_content...
     $person->first_name->xml_content('John');
     say $person->first_name->xml_content;
 
-    #Also...
-    $person->first_name([0,'John']);
-    #attributes, too...
+    # Setting attributes of an element
+    $xs->company->departments->department([0])->person([0])->salary({ 'jobgrade' => 10, 'exempt' => 1 });
+    # Or, using xml_attr...
+    $person->xml_attr({ skill => 'Perl', skill_level => 'intermediate'  });
+    say Data::Dumper::Dumper($person->xml_attr);
+    
+    # Or setting the string contents of an element and attribute values all at once...
     $person->first_name([0,'John',{'is_nice' => 'true'}]);
-    
-    #Write XML to a string
-    say $xs->xml_write;
-    
-    #Write XML to a string from a child element (returns a string reflecting the root element's XML)
-    say $person->xml_write;
-    
-    #A useful optional attribute
-    my $xs_2 = XML::Simple::Sugar->new({ xml => '<your_xml>here</your_xml>' });
-    
-    #Or... (this is dumb, don't do it)
-    my $xs_3 = XML::Simple::Sugar->new({ xml_data => { 'your_xml' => [{ 'content' => 'here' }] } });
- 
-    #Composing larger documents from other XML::Simple::Sugar objects
+
+Composing larger documents from other XML::Simple::Sugar objects
+
     my $xs=XML::Simple::Sugar->new();
     my $xs2=XML::Simple::Sugar->new();
     $xs2->table->tr->th([0,'First Name',{ style => 'text-align:left' }]);
@@ -361,13 +354,19 @@ version v1.0.2
     $xs->html->body->div->h1('Page Title')->xml_attr({ style => 'font-weight:bold' });
     $xs->html->body->div([1,$xs2]);
 
-=head2 MINIMUM PERL VERSION SUPPORTED
+=head1 DESCRIPTION
 
-Perl 5.18.2 or later is required by this module.  Lesser Perl versions struggle with deep recursion.  Patches welcome.
+This module is a wrapper around L<XML::Simple> to provide AUTOLOADed accessors to XML nodes.  
 
-=head1 VERSIONING
+=head1 WHY ANOTHER XML MODULE?
 
-Semantic versioning is adopted by this module. See L<http://semver.org/>.
+I wanted to write/manipulate simple XML payloads with more DWIMmery than what I found in modules available on CPAN (admittedly I didn't look very hard).  If the above syntax doesn't accomplish that for you, you should probably use a different module.
+
+Additionally, this package depends on L<XML::Simple>, which currently has a "do not use this module in new code" notice.  If you are cool with that, then so am I. :)
+
+=head1 PLEASE BE ADVISED
+
+Most of the automagic happens with AUTOLOAD.  Accessors/mutators and method names in this package cannot be used as element names in the XML document.  XML naming rules prohibit the use of elements starting with the string "xml", so I've used this string as a prefix to all accessors/mutators/methods to avoid potential conflicts with AUTOLOAD.  Sorry for the extra characters. :/ 
 
 =head1 ATTRIBUTES
 
@@ -377,7 +376,7 @@ This attribute determines on a per element basis whether new attributes or eleme
 
 =head2 xml_data (XML::Simple compliant Perl representation of an XML document)
 
-This is the Perl representation of the XML.  This is ugly to work with directly, hence this module.
+This is the Perl representation of the XML.  This is ugly to work with directly (hence this module), but in lieu of methods yet unwritten there may be a use case for having direct access to this structure.
 
 =head2 xml_index
 
@@ -393,7 +392,7 @@ The parent XML::Simple::Sugar object to the current element
 
 =head2 xml
 
-This readonly attribute is only useful during instantiation (XML::Simple::Sugar->new({ xml => $xml_string })).  This is particularly useful if you are working with an XML template.
+This readonly attribute is only useful during instantiation (XML::Simple::Sugar->new({ xml => $xml_string })).  This is primarily intended for working with XML templates, or XML service responses.
 
 =head2 xml_xs
 
@@ -429,20 +428,18 @@ This method removes the passed scalar argument from the element's list of attrib
 
 Merges another XML::Simple::Sugar object as a child of the current node.
 
-=head1 Why this module?
-
-I wanted to write/manipulate simple XML payloads with more DWIMmery than what I found in modules available on CPAN (admittedly I didn't look very hard).  If the above syntax doesn't accomplish that for you, you probably should use a different module.
-
-Additionally, this package depends on XML::Simple, which currently has a "do not use this module in new code" notice.  If you are cool with that, then so am I. :)
-
-=head1 PLEASE BE ADVISED
-
-Most of the automagic happens with AUTOLOAD.  Accessors/mutators and method names in this package cannot be used as element names in the XML document.  XML naming rules prohibit the use of elements starting with the string "xml", so I've used this string as a prefix to all accessors/mutators/methods to avoid potential conflicts with AUTOLOAD.  Sorry for the extra characters. :/ 
-
 =head1 REPOSITORY
 
 L<https://github.com/Camspi/XML-Simple-Sugar>
 
+=head1 MINIMUM PERL VERSION SUPPORTED
+
+Perl 5.18.2 or later is required by this module.  Lesser Perl versions struggle with deep recursion.  Patches welcome.
+
+=head1 VERSIONING
+
+Semantic versioning is adopted by this module. See L<http://semver.org/>.
+
 =head1 SEE ALSO
 
 =over 4
